==> python_datapack-1.21.3.69.tar.gz: python_datapack-1.21.3.69/src/python_datapack/resource_pack/source_lore_font.py <==

# Imports
from ..utils.io import *
from ..utils.print import *
from ..constants import *
from PIL import Image

# Utility functions
def main(config: dict) -> dict:
	namespace: str = config["namespace"]
	source_lore: list[dict|str] = config.get("source_lore", [])

	# If the source_lore has an ICON text component and original_icon is present,
	if source_lore and any(isinstance(component, dict) and "ICON" == component.get("text") for component in source_lore) and config.get("assets_folder"):
		original_icon: str = config["assets_folder"] + "/original_icon.png"
		if not os.path.exists(original_icon):
			return config

		# Create the font file
		write_to_file(
			f"{config['build_resource_pack']}/assets/{namespace}/font/icons.json",
			super_json_dump({"providers": [{"type": "bitmap","file": f"{namespace}:font/original_icon.png","ascent": 8,"height": 9,"chars": ["I"]}]})
		)

		# Copy the original icon to the resource pack
		img: Image.Image = Image.open(original_icon).convert("RGBA")
		img = img.resize((32, 32), Image.Resampling.NEAREST)
		destination: str = f"{config['build_resource_pack']}/assets/{namespace}/textures/font/original_icon.png"
		os.makedirs(os.path.dirname(destination), exist_ok=True)
		img.save(destination)

		# Replace every ICON text component with the original icon
		for component in source_lore:
			if isinstance(component, dict) and component.get("text") == "ICON":
				component["text"] = "I"
				component["color"] = "white"
				component["italic"] = False
				component["font"] = f"{namespace}:icons"
		source_lore.insert(0, "")
		config["source_lore"] = source_lore

	return config

==> python_datapack-1.21.4.82.tar.gz: python_datapack-1.21.4.82/src/python_datapack/resource_pack/source_lore_font.py <==

# Imports
from ..utils.io import *
from ..utils.print import *
from ..constants import *
from PIL import Image

# Utility functions
def main(config: dict) -> dict:
	namespace: str = config["namespace"]
	source_lore: list[dict|str] = config.get("source_lore", [])

	# If the source_lore has an ICON text component and original_icon is present,
	if source_lore and any(isinstance(component, dict) and "ICON" == component.get("text") for component in source_lore) and config.get("assets_folder"):
		original_icon: str = config["assets_folder"] + "/original_icon.png"
		if not os.path.exists(original_icon):
			return config

		# Create the font file
		write_to_file(
			f"{config['build_resource_pack']}/assets/{namespace}/font/icons.json",
			super_json_dump({"providers": [{"type": "bitmap","file": f"{namespace}:font/original_icon.png","ascent": 8,"height": 9,"chars": ["I"]}]})
		)

		# Copy the original icon to the resource pack
		destination: str = f"{config['build_resource_pack']}/assets/{namespace}/textures/font/original_icon.png"
		image: Image.Image = Image.open(original_icon).convert("RGB")
		if image.width > 256:
			image = image.resize((256, 256))
		image.save(destination)

		# Replace every ICON text component with the original icon
		for component in source_lore:
			if isinstance(component, dict) and component.get("text") == "ICON":
				component["text"] = "I"
				component["color"] = "white"
				component["italic"] = False
				component["font"] = f"{namespace}:icons"
		source_lore.insert(0, "")
		config["source_lore"] = source_lore

	return config
